# ia256utilities
***ia256utilities*** - is a set of useful utilities.

## Modules
* filesystem - load_json, save_json, save, save_binary, load_binary;
* hashfile - get_sha256;
* win - mklink.

## Installation
### pip and git
```
$ pip install git+git://github.com/IceArrow256/ia256utilities.git
```

### Just pip
```
$ pip install ia256utilities
```

## IDE
* PyCharm.

## License
***ia256utilities*** is licensed under The Unlicense, please see [LICENSE](https://github.com/IceArrow256/ia256utilities/blob/master/LICENSE) for details.

## Authors
* IceArrow256 - main developer (icearrow256@gmail.com);
* NikaDark16 - support (nikadark16@gmail.com).
